# HAICU

## Overview

Library for controlling HAICU MLD1200

## Installation

The recommended installation method is via pip

  To install:
    `pip install haicu`

  To upgrade:
    `pip install -U haicu`
